@@ -32,27 +32,20 @@ IntegerVector compute_closest_wgps_helper_no_sc(NumericVector a,
   omp_set_num_threads(nthread);
 #pragma omp parallel for
 #endif
-  for(int i = 0; i < size_b; ++i) {
+  for (int i = 0; i < size_b; ++i) {
 
     double tmp_val = 0;
+
+    double subtract_val = fabs((b[i] - a[0]));
+    double min_val = subtract_val;
     int min_index = 0;
-    double min_val = 0;
-    double subtract_val = 0;
 
-    for(int j=0; j < size_a; ++j) {
+    for (int j=1; j < size_a; ++j) {
 
-      subtract_val = (b[i]-a[j]);
-
-      if (subtract_val < 0){subtract_val *= -1;}
+      subtract_val = fabs((b[i] - a[j]));
 
       tmp_val =  subtract_val;
 
-      if (j==0){
-        min_val = tmp_val;
-        min_index = j;
-        continue;
-      }
-
       if (tmp_val < min_val){
         min_val = tmp_val;
         min_index = j;
